#' Semantic colors
#' https://github.com/Semantic-Org/Semantic-UI/blob/master/src/themes/default/globals/site.variables
#' @export
semantic_palette <- c("#A333C8", "#21BA45", "#2185D0", "#DB2828", "#F2711C", "#FBBD08", "#B5CC18",
                      "#00B5AD", "#6435C9", "#E03997", "#A5673F", "#767676", "#1B1C1D")
names(semantic_palette) <- c("purple", "green", "blue", "red", "orange", "yellow", "olive", "teal",
                             "violet", "pink", "brown", "grey", "black")

#' Checkbox positions
#'
#' @export
checkbox_positions <- c("grouped", "inline")
